import RPi.GPIO as GPIO
import time

GPIO.setwarnings(False)
GPIO.setmode(GPIO.BCM)       # Use BCM GPIO numbers

class Keypad:
	def __init__(self, keys, rowPins, colPins, Lcd):
		self.ROW = rowPins
		self.COL  = colPins
		self.keys = keys
		self.Lcd = Lcd
		self.key = set()
		for j in range(4):
			GPIO.setup(self.COL[j], GPIO.OUT)
			GPIO.output(self.COL[j], 1)

		for i in range(4):
			GPIO.setup(self.ROW[i], GPIO.IN, pull_up_down=GPIO.PUD_UP)

	def getKey(self):
		for i in range(4):
			GPIO.output(self.COL[i], 0)
			for j in range(4):
				if GPIO.input(self.ROW[j]) == 0:
					self.key.clear()
					self.key.add(self.keys[j][i])
					end = time.time() + 1
					while GPIO.input(self.ROW[j]) == 0 and time.time() < end:
						pass
			GPIO.output(self.COL[i], 1)
		if self.key:
			return self.key.pop()




from distutils.core import setup
setup(
	name = 'KeypadProteus',         # How you named your package folder (MyLib)
	packages = ['KeypadProteus'],   # Chose the same as "name"
	version = '0.1',      # Start with a small number and increase it with every change you make
	license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
	description = 'A library to control keypad in proteus ',   # Give a short description about your library
	author = 'Group 3',                   # Type in your name
	author_email = 'grapejam2312@gmail.com',      # Type in your E-Mail
	url = 'https://github.com/Hour-Sirak/Hour-Sirak',   # Provide either the link to your github or to your website
	download_url = 'https://github.com/Hour-Sirak/Hour-Sirak/archive/refs/tags/v_01.tar.gz',    # I explain this later on
	keywords = ['keypad', 'proteus'],   # Keywords that define your package best
	install_requires=[],
	classifiers=[
		'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
		'Intended Audience :: Developers',      # Define that your audience are developers
		'Topic :: Software Development :: Build Tools',
		'License :: OSI Approved :: MIT License',   # Again, pick a license
		'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
		'Programming Language :: Python :: 3.6',
	],
)